#[non_exhaustive]pub struct ReportOptions {
pub repository: Option<String>,
pub path_in_vcs: Option<String>,
pub vcs_ref: Option<String>,
}Expand description
Additional options for report generation
use ingredients::ReportOptions;
let mut options = ReportOptions::default();
options.repository = Some(String::from("https://example.com/foo/bar"));Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository: Option<String>Repository URL
This is useful if published crates do not contain a correct repository URL.
path_in_vcs: Option<String>Path in VCS
This is useful for crates that were published with old versions of cargo
that did not include the "path_in_vcs" property in .cargo_vcs_info.json
files.
vcs_ref: Option<String>VCS ref
This is useful for crates that were publsihed with old versions of cargo
that did not include a .cargo_vcs_info.json file on upload to crates.io.
Implementations